@@ -1,18 +1,22 @@
-from zeptomail import ZeptoMail
+import os
 
+from dotenv import load_dotenv
+
+from zeptomail import ZeptoMail
+env = load_dotenv()
 def main():
     # Replace with your actual API key
-    api_key = "your-api-key-here"
+    api_key = os.getenv('API_KEY')
     
     # Initialize the client
     client = ZeptoMail(api_key)
     
     # Create a recipient
-    recipient = client.add_recipient("recipient@example.com", "Recipient Name")
+    recipient = client.add_recipient(os.getenv('TEST_EMAIL'), "Recipient Name")
     
     # Send a simple email
     response = client.send_email(
-        from_address="sender@example.com",
+        from_address=os.getenv('SENDER_EMAIL'),
         from_name="Sender Name",
         to=[recipient],
         subject="Test Email from ZeptoMail Python API",
